@@ -15,29 +15,32 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-"""Dialog for selecting an image file to export."""
-
-import nfoview
-_ = nfoview.i18n._
-
 from gi.repository import GObject
 from gi.repository import Gtk
+from nfoview.i18n  import _
 
 __all__ = ("ExportImageDialog",)
 
+try:
+    # Available since GTK+ 3.20.
+    Base = Gtk.FileChooserNative
+except AttributeError:
+    Base = Gtk.FileChooserDialog
 
-class ExportImageDialog(Gtk.FileChooserDialog):
 
-    """Dialog for selecting an image file to export to."""
+class ExportImageDialog(Base):
 
     def __init__(self, parent):
-        """Initialize an :class:`ExportImageDialog` instance."""
         GObject.GObject.__init__(self)
         self.set_title(_("Export Image"))
         self.set_transient_for(parent)
         self.set_action(Gtk.FileChooserAction.SAVE)
-        self.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL)
-        self.add_button(Gtk.STOCK_SAVE, Gtk.ResponseType.OK)
+        if Base is Gtk.FileChooserNative:
+            self.set_cancel_label(_("_Cancel"))
+            self.set_accept_label(_("_Save"))
+        if Base is Gtk.FileChooserDialog:
+            self.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
+            self.add_button(_("_Save"), Gtk.ResponseType.OK)
+            self.set_default_response(Gtk.ResponseType.OK)
         self.set_do_overwrite_confirmation(True)
         self.set_select_multiple(False)
-        self.set_default_response(Gtk.ResponseType.OK)
